@@ -8,11 +8,12 @@ from dataclasses import dataclass, field, fields
 from datetime import datetime
 from enum import Enum, StrEnum
 from pathlib import Path
-from typing import Any, Optional, Sequence, Union
+from typing import Any, Generator, Iterable, Optional, Sequence, Union
 
 import json5
 import shtab
 from filelock import AsyncFileLock
+from pathspec import GitIgnoreSpec
 
 from vectorcode import __version__
 
@@ -76,6 +77,7 @@ class FilesAction(StrEnum):
 
 @dataclass
 class Config:
+    debug: bool = False
     no_stderr: bool = False
     recursive: bool = False
     include_hidden: bool = False
@@ -88,6 +90,7 @@ class Config:
     db_url: str = "http://127.0.0.1:8000"
     embedding_function: str = "SentenceTransformerEmbeddingFunction"  # This should fallback to whatever the default is.
     embedding_params: dict[str, Any] = field(default_factory=(lambda: {}))
+    embedding_dims: Optional[int] = None
     n_result: int = 1
     force: bool = False
     db_path: Optional[str] = "~/.local/share/vectorcode/chromadb/"
@@ -97,7 +100,7 @@ class Config:
     overlap_ratio: float = 0.2
     query_multiplier: int = -1
     query_exclude: list[Union[str, os.PathLike]] = field(default_factory=list)
-    reranker: Optional[str] = "CrossEncoderReranker"
+    reranker: Optional[str] = "NaiveReranker"
     reranker_params: dict[str, Any] = field(default_factory=lambda: {})
     check_item: Optional[str] = None
     use_absolute_path: bool = False
@@ -113,6 +116,9 @@ class Config:
     files_action: Optional[FilesAction] = None
     rm_paths: list[str] = field(default_factory=list)
 
+    def __hash__(self) -> int:
+        return hash(self.__repr__())
+
     @classmethod
     async def import_from(cls, config_dict: dict[str, Any]) -> "Config":
         """
@@ -135,6 +141,9 @@ class Config:
                 "embedding_params": config_dict.get(
                     "embedding_params", default_config.embedding_params
                 ),
+                "embedding_dims": config_dict.get(
+                    "embedding_dims", default_config.embedding_dims
+                ),
                 "db_url": config_dict.get("db_url", default_config.db_url),
                 "db_path": db_path,
                 "db_log_path": os.path.expanduser(
@@ -190,6 +199,12 @@ class Config:
 def get_cli_parser():
     __default_config = Config()
     shared_parser = argparse.ArgumentParser(add_help=False)
+    shared_parser.add_argument(
+        "--debug",
+        default=False,
+        action="store_true",
+        help="Enable debug mode.",
+    )
     chunking_parser = argparse.ArgumentParser(add_help=False)
     chunking_parser.add_argument(
         "--overlap",
@@ -415,6 +430,7 @@ async def parse_cli_args(args: Optional[Sequence[str]] = None):
         "action": CliAction(main_args.action),
         "project_root": main_args.project_root,
         "pipe": main_args.pipe,
+        "debug": main_args.debug,
     }
 
     match main_args.action:
@@ -671,3 +687,58 @@ class LockManager:
         if self.__locks.get(path) is None:
             self.__locks[path] = AsyncFileLock(path)  # pyright: ignore[reportArgumentType]
         return self.__locks[path]
+
+
+class SpecResolver:
+    """
+    This class is a wrapper around filespec that makes it easier to work with file specs that are not in cwd.
+    """
+
+    @classmethod
+    def from_path(cls, spec_path: str, project_root: Optional[str] = None):
+        """
+        Automatically determine the appropriate `base_dir` for resolving file specs that are outside of the project root.
+        Only supports `.gitignore` and `.vectorcode/vectorcode.{include,exclude}`.
+        Raises `ValueError` if the spec path is not one of them.
+        """
+        base_dir = "."
+        if spec_path.endswith(".gitignore"):
+            base_dir = spec_path.replace(".gitignore", "")
+        else:
+            path_obj = Path(spec_path)
+            if path_obj.name in {"vectorcode.include", "vectorcode.exclude"}:
+                if path_obj.parent.name == ".vectorcode":
+                    # project config
+                    base_dir = str(path_obj.parent.parent)
+                else:
+                    # assume to be global config
+                    base_dir = project_root or "."
+            else:  # pragma: nocover
+                raise ValueError(f"Unsupported spec path: {spec_path}")
+        return cls(spec_path, base_dir)
+
+    def __init__(self, spec: str | GitIgnoreSpec, base_dir: str = "."):
+        if isinstance(spec, str):
+            with open(spec) as fin:
+                self.spec = GitIgnoreSpec.from_lines(
+                    (i.strip() for i in fin.readlines())
+                )
+        else:
+            self.spec = spec
+        self.base_dir = base_dir
+
+    def match(
+        self, paths: Iterable[str], negated: bool = False
+    ) -> Generator[str, None, None]:
+        # get paths relative to `base_dir`
+
+        base = Path(self.base_dir).resolve()
+        for p in paths:
+            if base in Path(p).resolve().parents:
+                should_yield = self.spec.match_file(os.path.relpath(p, self.base_dir))
+                if negated:
+                    should_yield = not should_yield
+                if should_yield:
+                    yield p
+            else:
+                yield p
